@@ -591,7 +591,7 @@ public:
       return do_field_string;
     }
 
-    static void do_field_fbt_native_to_binary(Copy_field *copy)
+    static void do_field_fbt_native_to_binary(const Copy_field *copy)
     {
       NativeBuffer<FbtImpl::binary_length()+1> res;
       copy->from_field->val_native(&res);
@@ -772,9 +772,9 @@ public:
       Fbt_null tmp(arg);
       return m_null_value || tmp.is_null() ? UNKNOWN : m_native.cmp(tmp) != 0;
     }
-    int compare(const cmp_item *ci) const override
+    int compare(cmp_item *ci) override
     {
-      const cmp_item_fbt *tmp= static_cast<const cmp_item_fbt*>(ci);
+      cmp_item_fbt *tmp= static_cast<cmp_item_fbt*>(ci);
       DBUG_ASSERT(!m_null_value);
       DBUG_ASSERT(!tmp->m_null_value);
       return m_native.cmp(tmp->m_native);
@@ -788,13 +788,13 @@ public:
   class in_fbt :public in_vector
   {
     Fbt m_value;
-    static int cmp_fbt(void *cmp_arg, const void *a, const void *b)
+    static int cmp_fbt(void *cmp_arg, Fbt *a, Fbt *b)
     {
-      return static_cast<const Fbt*>(a)->cmp(*static_cast<const Fbt*>(b));
+      return a->cmp(*b);
     }
   public:
     in_fbt(THD *thd, uint elements)
-     :in_vector(thd, elements, sizeof(Fbt), cmp_fbt, 0),
+     :in_vector(thd, elements, sizeof(Fbt), (qsort2_cmp) cmp_fbt, 0),
       m_value(Fbt::zero())
     { }
     const Type_handler *type_handler() const override
